@@ -8,6 +8,12 @@ except ImportError:
     from pathlib2 import Path, PurePath                         # type: ignore
 
 
+try:
+    from contextlib import suppress
+except ImportError:
+    from contextlib2 import suppress                         # type: ignore
+
+
 try:
     from functools import singledispatch
 except ImportError:
